diff --git a/test/Microsoft.AspNetCore.Localization.FunctionalTests/TestRunner.cs b/test/Microsoft.AspNetCore.Localization.FunctionalTests/TestRunner.cs
index ea1702bcdd..436eef991e 100644
--- a/test/Microsoft.AspNetCore.Localization.FunctionalTests/TestRunner.cs
+++ b/test/Microsoft.AspNetCore.Localization.FunctionalTests/TestRunner.cs
@@ -42,7 +42,7 @@ namespace Microsoft.AspNetCore.Localization.FunctionalTests
{
var deploymentResult = deployer.Deploy();
- var cookie = new Cookie("ASPNET_CULTURE", "c=" + locale + "|uic=" + locale);
+ var cookie = new Cookie(CookieRequestCultureProvider.DefaultCookieName, "c=" + locale + "|uic=" + locale);
var cookieContainer = new CookieContainer();
cookieContainer.Add(new Uri(deploymentResult.ApplicationBaseUri), cookie);
diff --git a/test/Microsoft.AspNetCore.Localization.FunctionalTests/project.json b/test/Microsoft.AspNetCore.Localization.FunctionalTests/project.json
index c39676a3be..115313872e 100644
--- a/test/Microsoft.AspNetCore.Localization.FunctionalTests/project.json
+++ b/test/Microsoft.AspNetCore.Localization.FunctionalTests/project.json
@@ -3,6 +3,7 @@
"warningsAsErrors": true
},
"dependencies": {
+ "Microsoft.AspNetCore.Localization": "1.0.0-*",
"Microsoft.AspNetCore.Server.Testing": "1.0.0-*",
"Microsoft.Extensions.Logging": "1.0.0-*",
"Microsoft.Extensions.Logging.Console": "1.0.0-*",
diff --git a/src/Microsoft.AspNetCore.Localization/CookieRequestCultureProvider.cs b/src/Microsoft.AspNetCore.Localization/CookieRequestCultureProvider.cs
index bbbf0e3137..67ecbdf53c 100644
--- a/src/Microsoft.AspNetCore.Localization/CookieRequestCultureProvider.cs
+++ b/src/Microsoft.AspNetCore.Localization/CookieRequestCultureProvider.cs
@@ -2,11 +2,8 @@
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
using System;
-using System.Collections.Generic;
-using System.Globalization;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
-using Microsoft.Extensions.Globalization;
namespace Microsoft.AspNetCore.Localization
{
@@ -20,9 +17,9 @@ namespace Microsoft.AspNetCore.Localization
private static readonly string _uiCulturePrefix = "uic=";
///
/// Represent the default cookie name used to track the user's preferred culture information, which is "ASPNET_CULTURE".
///
- public static readonly string DefaultCookieName = "ASPNET_CULTURE";
+ public static readonly string DefaultCookieName = ".AspNetCore.Culture";
///
/// The name of the cookie that contains the user's preferred culture information.
@@ -20,9 +17,9 @@ namespace Microsoft.AspNetCore.Localization
private static readonly string _uiCulturePrefix = "uic=";
///
- /// Represent the default cookie name used to track the user's preferred culture information, which is "ASPNET_CULTURE".
+ /// Represent the default cookie name used to track the user's preferred culture information, which is ".AspNetCore.Culture".
///